@@ -39,6 +39,7 @@
 #endif
 
 #include "agent.h"
+#include "test-common.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -329,21 +330,6 @@ static void set_candidates (NiceAgent *from, guint from_stream,
   g_slist_free (cands);
 }
 
-static void set_credentials (NiceAgent *lagent, guint lstream,
-    NiceAgent *ragent, guint rstream)
-{
-  gchar *ufrag = NULL, *password = NULL;
-
-  nice_agent_get_local_credentials(lagent, lstream, &ufrag, &password);
-  nice_agent_set_remote_credentials (ragent, rstream, ufrag, password);
-  g_free (ufrag);
-  g_free (password);
-  nice_agent_get_local_credentials(ragent, rstream, &ufrag, &password);
-  nice_agent_set_remote_credentials (lagent, lstream, ufrag, password);
-  g_free (ufrag);
-  g_free (password);
-}
-
 static guint16
 get_port (NiceAgent *agent, guint stream_id, guint component_id)
 {
@@ -352,14 +338,14 @@ get_port (NiceAgent *agent, guint stream_id, guint component_id)
   GSList *item;
   guint16 port = 0;
 
-  g_assert (cands != NULL);
+  g_assert_true (cands != NULL);
 
   for (item = cands; item; item = item->next) {
     NiceCandidate *cand = item->data;
     port = nice_address_get_port (&cand->addr);
     break;
   }
-  g_assert (port != 0);
+  g_assert_true (port != 0);
 
   g_slist_free_full (cands, (GDestroyNotify) nice_candidate_free);
 
@@ -419,12 +405,12 @@ static int run_full_test (NiceAgent *lagent, NiceAgent *ragent, NiceAddress *bas
 
   nice_agent_set_port_range (ragent, rs_id, 2, port, port);
 
-  g_assert (nice_agent_gather_candidates (ragent, rs_id) == FALSE);
-  g_assert (nice_agent_get_local_candidates (ragent, rs_id, 1) == NULL);
-  g_assert (nice_agent_get_local_candidates (ragent, rs_id, 2) == NULL);
+  g_assert_true (nice_agent_gather_candidates (ragent, rs_id) == FALSE);
+  g_assert_true (nice_agent_get_local_candidates (ragent, rs_id, 1) == NULL);
+  g_assert_true (nice_agent_get_local_candidates (ragent, rs_id, 2) == NULL);
   nice_agent_set_port_range (ragent, rs_id, 2, 0, 0);
-  g_assert (nice_agent_gather_candidates (lagent, ls_id) == TRUE);
-  g_assert (nice_agent_gather_candidates (ragent, rs_id) == TRUE);
+  g_assert_true (nice_agent_gather_candidates (lagent, ls_id) == TRUE);
+  g_assert_true (nice_agent_gather_candidates (ragent, rs_id) == TRUE);
 
 #if USE_LOOPBACK
   {
@@ -486,11 +472,11 @@ static int run_full_test (NiceAgent *lagent, NiceAgent *ragent, NiceAddress *bas
       global_ragent_gathering_done != TRUE) {
     g_debug ("test-fullmode: Added streams, running mainloop until 'candidate-gathering-done'...");
     g_main_loop_run (global_mainloop);
-    g_assert (global_lagent_gathering_done == TRUE);
-    g_assert (global_ragent_gathering_done == TRUE);
+    g_assert_true (global_lagent_gathering_done == TRUE);
+    g_assert_true (global_ragent_gathering_done == TRUE);
   }
 
-  set_credentials (lagent, ls_id, ragent, rs_id);
+  test_common_set_credentials (lagent, ls_id, ragent, rs_id);
 
   /* step: pass the remote candidates to agents  */
   set_candidates (ragent, rs_id, lagent, ls_id, NICE_COMPONENT_TYPE_RTP, USE_TURN);
@@ -505,8 +491,8 @@ static int run_full_test (NiceAgent *lagent, NiceAgent *ragent, NiceAddress *bas
   g_main_loop_run (global_mainloop);
 
   /* note: verify that STUN binding requests were sent */
-  g_assert (global_lagent_ibr_received == TRUE);
-  g_assert (global_ragent_ibr_received == TRUE);
+  g_assert_true (global_lagent_ibr_received == TRUE);
+  g_assert_true (global_ragent_ibr_received == TRUE);
 
   /* note: test payload send and receive */
   global_ragent_read = 0;
@@ -609,11 +595,11 @@ static int run_full_test_delayed_answer (NiceAgent *lagent, NiceAgent *ragent, N
       global_ragent_gathering_done != TRUE) {
     g_debug ("test-fullmode: Added streams, running mainloop until 'candidate-gathering-done'...");
     g_main_loop_run (global_mainloop);
-    g_assert (global_lagent_gathering_done == TRUE);
-    g_assert (global_ragent_gathering_done == TRUE);
+    g_assert_true (global_lagent_gathering_done == TRUE);
+    g_assert_true (global_ragent_gathering_done == TRUE);
   }
 
-  set_credentials (lagent, ls_id, ragent, rs_id);
+  test_common_set_credentials (lagent, ls_id, ragent, rs_id);
 
   /* step: set remote candidates for agent R (answering party) */
   /* We have to disable TURN for this test because with the delayed answer,
@@ -628,7 +614,7 @@ static int run_full_test_delayed_answer (NiceAgent *lagent, NiceAgent *ragent, N
   global_exit_when_ibr_received = 0;
 
   /* note: verify that STUN binding requests were sent */
-  g_assert (global_lagent_ibr_received == TRUE);
+  g_assert_true (global_lagent_ibr_received == TRUE);
 
   g_debug ("test-fullmode: Delayed answer received, continuing processing..");
 
@@ -639,7 +625,7 @@ static int run_full_test_delayed_answer (NiceAgent *lagent, NiceAgent *ragent, N
   g_debug ("test-fullmode: Running mainloop until connectivity checks succeeed.");
 
   g_main_loop_run (global_mainloop);
-  g_assert (global_ragent_ibr_received == TRUE);
+  g_assert_true (global_ragent_ibr_received == TRUE);
   g_assert_cmpuint (global_components_failed, ==, 0);
 
   /* note: test payload send and receive */
@@ -730,13 +716,13 @@ static int run_full_test_wrong_password (NiceAgent *lagent, NiceAgent *ragent, N
       global_ragent_gathering_done != TRUE) {
     g_debug ("test-fullmode: Added streams, running mainloop until 'candidate-gathering-done'...");
     g_main_loop_run (global_mainloop);
-    g_assert (global_lagent_gathering_done == TRUE);
-    g_assert (global_ragent_gathering_done == TRUE);
+    g_assert_true (global_lagent_gathering_done == TRUE);
+    g_assert_true (global_ragent_gathering_done == TRUE);
   }
 
   g_debug ("test-fullmode: Got local candidates...");
 
-  set_credentials (lagent, ls_id, ragent, rs_id);
+  test_common_set_credentials (lagent, ls_id, ragent, rs_id);
   nice_agent_set_remote_credentials (ragent, rs_id, "wrong", "password");
   nice_agent_set_remote_credentials (lagent, ls_id, "wrong2", "password2");
 
@@ -817,13 +803,13 @@ static int run_full_test_control_conflict (NiceAgent *lagent, NiceAgent *ragent,
       global_ragent_gathering_done != TRUE) {
     g_debug ("test-fullmode: Added streams, running mainloop until 'candidate-gathering-done'...");
     g_main_loop_run (global_mainloop);
-    g_assert (global_lagent_gathering_done == TRUE);
-    g_assert (global_ragent_gathering_done == TRUE);
+    g_assert_true (global_lagent_gathering_done == TRUE);
+    g_assert_true (global_ragent_gathering_done == TRUE);
   }
 
   g_debug ("test-fullmode: Got local candidates...");
 
-  set_credentials (lagent, ls_id, ragent, rs_id);
+  test_common_set_credentials (lagent, ls_id, ragent, rs_id);
 
   /* step: pass the remote candidates to agents  */
   set_candidates (ragent, rs_id, lagent, ls_id, NICE_COMPONENT_TYPE_RTP, USE_TURN);
@@ -965,17 +951,17 @@ int main (void)
     guint port = 0;
     gboolean mode = FALSE;
     g_object_get (G_OBJECT (lagent), "stun-server", &string, NULL);
-    g_assert (stun_server == NULL || strcmp (string, stun_server) == 0);
+    g_assert_true (stun_server == NULL || strcmp (string, stun_server) == 0);
     g_free (string);
     g_object_get (G_OBJECT (lagent), "stun-server-port", &port, NULL);
-    g_assert (stun_server_port == NULL || port == (guint)atoi (stun_server_port));
+    g_assert_true (stun_server_port == NULL || port == (guint)atoi (stun_server_port));
     g_object_get (G_OBJECT (lagent), "proxy-ip", &string, NULL);
     g_assert_cmpstr (string, ==, PROXY_IP);
     g_free (string);
     g_object_get (G_OBJECT (lagent), "proxy-port", &port, NULL);
     g_assert_cmpuint (port, ==, PROXY_PORT);
     g_object_get (G_OBJECT (lagent), "controlling-mode", &mode, NULL);
-    g_assert (mode == TRUE);
+    g_assert_true (mode == TRUE);
     g_object_set (G_OBJECT (lagent), "max-connectivity-checks", 300, NULL);
     g_object_get (G_OBJECT (lagent), "max-connectivity-checks", &max_checks, NULL);
     g_assert_cmpuint (max_checks, ==, 300);
@@ -1067,9 +1053,9 @@ int main (void)
   priv_print_global_status ();
   g_assert_cmpint (result, ==, 0);
   /* should FAIL as agent L can't send any checks: */
-  g_assert (global_lagent_state[0] == NICE_COMPONENT_STATE_FAILED ||
+  g_assert_true (global_lagent_state[0] == NICE_COMPONENT_STATE_FAILED ||
 	    global_lagent_state[1] == NICE_COMPONENT_STATE_FAILED);
-  g_assert (global_lagent_state[0] == NICE_COMPONENT_STATE_FAILED ||
+  g_assert_true (global_lagent_state[0] == NICE_COMPONENT_STATE_FAILED ||
 	    global_lagent_state[1] == NICE_COMPONENT_STATE_FAILED);
 #endif
 
@@ -1079,13 +1065,13 @@ int main (void)
   priv_print_global_status ();
   /* should SUCCEED as agent L can send the checks: */
   g_assert_cmpint (result, ==, 0);
-  g_assert (global_lagent_state[0] == NICE_COMPONENT_STATE_CONNECTED ||
+  g_assert_true (global_lagent_state[0] == NICE_COMPONENT_STATE_CONNECTED ||
       global_lagent_state[0] == NICE_COMPONENT_STATE_READY);
-  g_assert (global_lagent_state[1] == NICE_COMPONENT_STATE_CONNECTED ||
+  g_assert_true (global_lagent_state[1] == NICE_COMPONENT_STATE_CONNECTED ||
       global_lagent_state[1] == NICE_COMPONENT_STATE_READY);
-  g_assert (global_ragent_state[0] == NICE_COMPONENT_STATE_CONNECTED ||
+  g_assert_true (global_ragent_state[0] == NICE_COMPONENT_STATE_CONNECTED ||
       global_ragent_state[0] == NICE_COMPONENT_STATE_READY);
-  g_assert(global_ragent_state[1] == NICE_COMPONENT_STATE_CONNECTED ||
+  g_assert_true (global_ragent_state[1] == NICE_COMPONENT_STATE_CONNECTED ||
       global_ragent_state[1] == NICE_COMPONENT_STATE_READY);
   g_object_set (G_OBJECT (lagent), "max-connectivity-checks", 100, NULL);
 
